<?php

/*
Plugin Name: Maco Extra
Plugin URI: http://www.themesawesome.com
Description: A plugin to add functionality to Premium Theme Maco from Themes Awesome
Version: 1.0.0
Author: Themes Awesome
Author URI: http://www.themesawesome.com
License: GPL2
*/

if ( ! defined( 'ABSPATH' ) ) exit;

// This file is pretty much a boilerplate WordPress plugin.
// It does very little except including wp-widget.php

define( 'MACO_EXTRA__FILE__', __FILE__ );
define( 'MACO_EXTRA_PLUGIN_BASE', plugin_basename( MACO_EXTRA__FILE__ ) );
define( 'MACO_EXTRA_URL', plugins_url( '/', MACO_EXTRA__FILE__ ) );
define( 'MACO_EXTRA_PATH', plugin_dir_path( MACO_EXTRA__FILE__ ) );

require_once MACO_EXTRA_PATH.'inc/custom.php';
require_once MACO_EXTRA_PATH.'inc/portohov.php';
require_once MACO_EXTRA_PATH.'inc/element-helper.php';
require_once MACO_EXTRA_PATH.'inc/lightbox-transition.php';

// Flush rewrite rules on activation
function maco_extra_activation() {
	flush_rewrite_rules(true);
}

require_once MACO_EXTRA_PATH.'widgets/maco-latestpost-widget.php';
require_once MACO_EXTRA_PATH.'widgets/maco-portfolio-widget.php';

function maco_new_elements( $widgets_manager ) {

	require_once MACO_EXTRA_PATH.'head-title/head-title.php';
	require_once MACO_EXTRA_PATH.'maco-post/post-control.php';
	require_once MACO_EXTRA_PATH.'maco-portfolio/portfolio-control.php';
	require_once MACO_EXTRA_PATH.'gallery-block/gallery-control.php';
	require_once MACO_EXTRA_PATH.'team-block/team-control.php';
	require_once MACO_EXTRA_PATH.'client-block/client-control.php';
	require_once MACO_EXTRA_PATH.'contact-block/contact-control.php';
	require_once MACO_EXTRA_PATH.'testimonial-block/testimonial-control.php';
	require_once MACO_EXTRA_PATH.'text-block/text-control.php';

	$widgets_manager->register( new \maco_client_block() );
	$widgets_manager->register( new \maco_post_block() );
	$widgets_manager->register( new \maco_portfolio_block() );
	$widgets_manager->register( new \maco_gallery() );
	$widgets_manager->register( new \maco_team_block() );
	$widgets_manager->register( new \maco_head_title() );
	$widgets_manager->register( new \maco_contact_form() );
	$widgets_manager->register( new \maco_testimonial_block() );
	$widgets_manager->register( new \maco_text() );
}

add_action('elementor/widgets/register','maco_new_elements');

/*-----------------------------------------------------------------------------------*/
/* The Portfolio custom post type
/*-----------------------------------------------------------------------------------*/

add_action('init', 'maco_portfolio_register'); 
function maco_portfolio_register() { 

	$labels = array(
		'name'               => _x('Portfolio', 'Portfolio General Name', 'maco'),
		'singular_name'      => _x('Portfolio', 'Portfolio Singular Name', 'maco'),
		'add_new'            => _x('Add New', 'Add New Portfolio Name', 'maco'),
		'add_new_item'       => __('Add New Portfolio', 'maco'),
		'edit_item'          => __('Edit Portfolio', 'maco'),
		'new_item'           => __('New Portfolio', 'maco'),
		'view_item'          => __('View Portfolio', 'maco'),
		'search_items'       => __('Search Portfolio', 'maco'),
		'not_found'          => __('Nothing found', 'maco'),
		'not_found_in_trash' => __('Nothing found in Trash', 'maco'),
		'parent_item_colon'  => ''
	);

	$args = array(
		'labels'        => $labels,
		'public'        => true,
		'publicly_queryable'  => true,
		'show_ui'       => true,
		'query_var'       => 'portfolio',
		'capability_type'   => 'post',
		'hierarchical'      => false,
		'rewrite'       => false,
		'supports'        => array('title','editor','thumbnail', 'post-formats'),
		'menu_position'     => 5,
	); 

	register_post_type('maco-portfolio' , $args);

	register_taxonomy(
		"portfolio-category", array("maco-portfolio"), array(
		"hierarchical"    => true,
		"label"       => "Categories", 
		"singular_label"  => "Categories", 
		"rewrite"     => true)
	);

	register_taxonomy_for_object_type('portfolio-category', 'maco-portfolio'); 

}

add_filter("manage_edit-portfolio_columns", "maco_portfolio_edit_columns"); 
function maco_portfolio_edit_columns($columns) {  
	$columns = array(
		"cb"			=> "<input type=\"checkbox\" />",
		"title"			=> __('Portfolio', 'maco'),
		"categories"	=> __('Categories', 'maco'),
	);
	return $columns;  
}

add_action("manage_portfolio_posts_custom_column",  "maco_portfolio_custom_columns");
function maco_portfolio_custom_columns($column, $post_id) {  
	global $post;
	switch ($column) {
	case "categories":
		echo get_the_term_list($post->ID, 'portfolio-category', '', ', ','');
	break;
	}
}

/* DEMO IMPORT */

function maco_ocdi_import_files() {
return array(
array(
  'import_file_name'           => 'Demo Import 1',
  'import_file_url'            => plugin_dir_url( __FILE__ ).'demo-content/demo1/content.xml',
  'import_redux'               => array(
	array(
	'file_url'    => plugin_dir_url( __FILE__ ).'demo-content/demo1/theme-options.json',
	'option_name' => 'maco_framework',
	),
  ),
  'import_preview_image_url'   => plugin_dir_url( __FILE__ ).'demo-content/demo1/screen-image.jpg',
  'import_notice'              => __( 'Some of images may not looks like demo because images are excluded from theme.', 'maco' ),
  'preview_url'                => 'https://maco.themesawesome.com/',
  ),

);
}
add_filter( 'pt-ocdi/import_files', 'maco_ocdi_import_files' );

function maco_ocdi_after_import_setup() {
// Assign menus to their locations.
$main_menu = get_term_by( 'name', 'Menu', 'nav_menu' );

set_theme_mod( 'nav_menu_locations', array(
  'header-menu' => $main_menu->term_id, // replace 'main-menu' here with the menu location identifier from register_nav_menu() function
  )
);

// Assign front page and posts page (blog page).
$front_page_id = get_page_by_title( 'Home' );
$blog_page_id  = get_page_by_title( 'Blog' );

update_option( 'show_on_front', 'page' );
update_option( 'page_on_front', $front_page_id->ID );
update_option( 'page_for_posts', $blog_page_id->ID );


}
add_action( 'pt-ocdi/after_import', 'maco_ocdi_after_import_setup' );