<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

include ( plugin_dir_path(__FILE__).'config/post-post-setting.php' );
include ( plugin_dir_path(__FILE__).'config/post-layout-setting.php' );
include ( plugin_dir_path(__FILE__).'config/post-pagination-setting.php' );

class maco_post_block extends \Elementor\Widget_Base {

	public function get_name() {
		return 'maco-post-block';
	}

	public function get_title() {
		return __( 'Post', 'maco' );
	}

	public function get_icon() {
		return 'eicon-post-list';
	}

	public function get_categories() {
		return [ 'maco-general-category' ];
	}

	protected function register_controls() {
		/*-----------------------------------------------------------------------------------
			POST BLOCK INDEX
			1. ELEMENT SETTING
			2. POST SETTING
			3. LAYOUT SETTING
			4. IMAGE SETTING
			5. TITLE STYLE SETTING
				5.1. Title Style Grid Porfo
			6. META STYLE SETTING
				6.1. Category Style Setting
				6.2. Author Style Setting
				6.3. Date Style Setting
			7. EXCERPT STYLE SETTING
			8. READ MORE STYLE SETTING
			9. CAROUSEL STYLE SETTING
			10. PAGINATION STYLE SETTING
		-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  2. POST SETTING
		/*-----------------------------------------------------------------------------------*/
		$this->start_controls_section(
			'section_maco_post_block_post_setting',
			[
				'label' => __( 'Post Setting', 'maco' ),
			]
		);

		/* go to this folder > config > post-post-setting.php*/

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block post setting
		-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  3. LAYOUT SETTING
		/*-----------------------------------------------------------------------------------*/
		$this->start_controls_section(
			'section_maco_post_block_layout_setting',
			[
				'label' => __( 'Layout Setting', 'maco' ),
			]
		);

		/* go to this folder > config > post-layout-setting.php*/

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block layout setting
		-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  4. IMAGE SETTING
		/*-----------------------------------------------------------------------------------*/
		$this->start_controls_section(
			'section_maco_post_block_image_setting',
			[
				'label' => __( 'Image Setting', 'maco' ),
			]
		);

		$this->add_control(
			'image_overlay_bg',
			[
				'label' => __( 'Overlay Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => 'rgba(0, 0, 0, 0.4)',
				'selectors' => [
					'{{WRAPPER}} .blog-item .post-thumb .maco-overlay' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'width',
			[
				'label' => __( 'Width', 'maco' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '535',
				'title' => __( 'Enter some text', 'maco' ),
				'description' => __( 'For Default Post Style, only work when assigned as horizontal item.', 'maco' ),
			]
		);

		$this->add_control(
			'height',
			[
				'label' => __( 'Height', 'maco' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => '355',
				'title' => __( 'Enter some text', 'maco' ),
				'selectors' => [
					'{{WRAPPER}} .blog-section.blog-style-2 article.blog-item, {{WRAPPER}} .main-news-1 .blog-wrap' => 'height: {{SIZE}}px;',
				],
			]
		);

		$this->add_control(
			'post_image_crop',
			[
				'label' => __( 'Force to Crop Image', 'maco' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => 'Use',
				'label_off' => 'No',
				'return_value' => 'on',
				'default' => 'on',
			]
		);

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block image setting
		-----------------------------------------------------------------------------------*/
		
		/*-----------------------------------------------------------------------------------*/
		/*  5. TITLE STYLE SETTING
		/*-----------------------------------------------------------------------------------*/
		$this->start_controls_section(
		'section_maco_post_block_title_style_setting',
			[
				'label' => __( 'Title Setting', 'maco' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'use_title',
			[
				'label' => __( 'Use Title', 'maco' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => 'Use',
				'label_off' => 'No',
				'return_value' => 'on',
				'default' => 'on',
			]
		);

		$this->add_responsive_control(
			'text_align_title_left',
			[
				'label' => __( 'Title Align', 'maco' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'maco' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'maco' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'maco' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .post-title, {{WRAPPER}} .blog-item .post-meta' => 'text-align: {{VALUE}};',
				],
				'default' => 'left',
				'condition' => [
					'use_title' => 'on',
				],
			]
		);

		/*-----------------------------------------------------------------------------------*/
		/*  5.1. Title Style Grid Porfo
		/*-----------------------------------------------------------------------------------*/
		$this->add_control(
			'typhography_title_color',
			[
				'label' => __( 'Title Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .blog-item .post-content .post-title a' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_title' => 'on',
				],
			]
		);

		$this->add_control(
			'typhography_title_hov_color',
			[
				'label' => __( 'Title Hover Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#666666',
				'selectors' => [
					'{{WRAPPER}} .blog-item .post-content .post-title a:hover' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_title' => 'on',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'typography_post_title',
				'label' => __( 'Title Font Setting', 'maco' ),
				'selector' => '{{WRAPPER}} .blog-item .post-content .post-title',
				'condition' => [
					'use_title' => 'on',
				],
			]
		);

		$this->add_responsive_control(
			'title_min_height',
			[
				'label' => __( 'Title Minimum Height', 'maco' ),
				'description' => __( 'Use in case you want to make all title have same height.', 'maco' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .post-title' => 'min-height: {{VALUE}}px',
				],
				'condition' => [
					'use_title' => 'on',
				],
			]
		);

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block title style setting
		-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  6. META STYLE SETTING
		/*-----------------------------------------------------------------------------------*/

		/*====== 6.1. Category Style Setting =======*/
		$this->start_controls_section(
		'section_maco_post_block_category_style_setting',
			[
				'label' => __( 'Category Setting', 'maco' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'use_category',
			[
				'label' => __( 'Use Category Text', 'maco' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => 'Use',
				'label_off' => 'No',
				'return_value' => 'on',
				'default' => 'on',
			]
		);

		$this->add_responsive_control(
			'text_align_category_left',
			[
				'label' => __( 'Category Align', 'maco' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'maco' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'maco' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'maco' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .standard-post-categories' => 'text-align: {{VALUE}};',
				],
				'default' => 'left',
				'condition' => [
					'use_category' => 'on',
				],
			]
		);

		$this->add_control(
			'typhography_category_color',
			[
				'label' => __( 'Category Text Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .standard-post-categories a' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_category' => 'on',
				],
			]
		);

		$this->add_control(
			'typhography_category_bg',
			[
				'label' => __( 'Category Background Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#cb1313',
				'selectors' => [
					'{{WRAPPER}} .standard-post-categories a' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'use_category' => 'on',
				],
			]
		);

		$this->add_control(
			'category_link_hov_color_grid2',
			[
				'label' => __( 'Category Link Hover Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .standard-post-categories a:hover' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_category' => 'on',
				],
			]
		);

		$this->add_control(
			'typhography_category_bg_hov',
			[
				'label' => __( 'Category Background Hover', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#cc4f4f',
				'selectors' => [
					'{{WRAPPER}} .standard-post-categories a:hover' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'use_category' => 'on',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'typography_post_category',
				'label' => __( 'Category Font Setting', 'maco' ),
				'selector' => '{{WRAPPER}} .standard-post-categories a, {{WRAPPER}} .post-masonry-style .loop-content .category a, {{WRAPPER}} .category-main-news-1 a',
				'condition' => [
					'use_category' => 'on',
				],
			]
		);

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block category style setting
		-----------------------------------------------------------------------------------*/

		/*====== 6.2. Author Style Setting =======*/
		$this->start_controls_section(
		'section_maco_post_block_author_style_setting',
			[
				'label' => __( 'Author Setting', 'maco' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'use_author',
			[
				'label' => __( 'Use Author Text', 'maco' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => 'Use',
				'label_off' => 'No',
				'return_value' => 'on',
				'default' => 'on',
			]
		);

		$this->add_control(
			'typhography_author_color',
			[
				'label' => __( 'Author Text Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .author span, {{WRAPPER}} .author a, {{WRAPPER}} .blog-item .meta-wrapper span.author:after, {{WRAPPER}} .main-news-5 .post-content .post-author-name' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_author' => 'on',
				],
			]
		);

		$this->add_control(
			'author_link_hov_color',
			[
				'label' => __( 'Author Link Hover Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .author a:hover, {{WRAPPER}} .main-news-5 .post-content .post-author-name:hover' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_author' => 'on',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'typography_post_author',
				'label' => __( 'Author Font Setting', 'maco' ),
				'selector' => '{{WRAPPER}} .author a, {{WRAPPER}} .author span, {{WRAPPER}} .main-news-5 .post-content .post-author-name',
				'condition' => [
					'use_author' => 'on',
				],
			]
		);

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block author style setting
		-----------------------------------------------------------------------------------*/

		/*====== 6.3. Date Style Setting =======*/
		$this->start_controls_section(
		'section_maco_post_block_date_style_setting',
			[
				'label' => __( 'Date Setting', 'maco' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'use_date',
			[
				'label' => __( 'Use Date Text', 'maco' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => 'Use',
				'label_off' => 'No',
				'return_value' => 'on',
				'default' => 'on',
			]
		);

		$this->add_control(
			'typhography_date_color',
			[
				'label' => __( 'Date Text Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .date span, {{WRAPPER}} .date a, {{WRAPPER}} .blog-item .meta-wrapper span.date:before, {{WRAPPER}} .post-masonry-style .loop-content .date, {{WRAPPER}} .main-news-5 .post-content .post-date, {{WRAPPER}} .the-post-head .meta-info .span-head:after' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_date' => 'on',
				],
			]
		);

		$this->add_control(
			'date_link_hov_color',
			[
				'label' => __( 'Date Link Hover Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .date a:hover, {{WRAPPER}} .post-masonry-style .loop-content .date:hover, {{WRAPPER}} .main-news-5 .post-content .post-date:hover' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_date' => 'on',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'typography_post_date',
				'label' => __( 'Date Font Setting', 'maco' ),
				'selector' => '{{WRAPPER}} .date span, {{WRAPPER}} .date a, {{WRAPPER}} .post-masonry-style .loop-content .date, {{WRAPPER}} .main-news-5 .post-content .post-date',
				'condition' => [
					'use_date' => 'on',
				],
			]
		);

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block date style setting
		-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  7. EXCERPT STYLE SETTING
		/*-----------------------------------------------------------------------------------*/
		$this->start_controls_section(
		'section_maco_post_block_excerpt_style_setting',
			[
				'label' => __( 'Excerpt Setting', 'maco' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		/*===========Typhography Excerpt=============*/
		$this->add_control(
			'use_excerpt',
			[
				'label' => __( 'Use Excerpt Block', 'maco' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => 'Use',
				'label_off' => 'No',
				'return_value' => 'on',
				'default' => 'on',
			]
		);

		$this->add_responsive_control(
			'text_align_excerpt_left',
			[
				'label' => __( 'Excerpt Align', 'maco' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'maco' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'maco' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'maco' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .blog-item .post-text, {{WRAPPER}} .grid .post-text' => 'text-align: {{VALUE}};',
				],
				'default' => 'left',
				'condition' => [
					'use_excerpt' => 'on',
				],
			]
		);

		$this->add_control(
			'typhography_excerpt_color',
			[
				'label' => __( 'Excerpt Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => 'rgba(0,0,0,0.8)',
				'selectors' => [
					'{{WRAPPER}} .post-text p, {{WRAPPER}} .post-text' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_excerpt' => 'on',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'typography_post_excerpt',
				'label' => __( 'Excerpt Font Setting', 'maco' ),
				'selector' => '{{WRAPPER}} .post-text p',
				'condition' => [
					'use_excerpt' => 'on',
				],
			]
		);

		$this->add_control(
			'excerpt_word',
			[
				'label' => __( 'Word Count for Post', 'maco' ),
				'description' => __( 'Margin right for each item inside this block.', 'maco' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '30',
				'condition' => [
					'use_excerpt' => 'on',
				],	
			]
		);

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block excerpt style setting
		-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  8. READ MORE STYLE SETTING
		/*-----------------------------------------------------------------------------------*/
		$this->start_controls_section(
		'section_maco_post_block_readmore_style_setting',
			[
				'label' => __( 'Read More Setting', 'maco' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		//==========Read More==========//
		$this->add_control(
			'use_read_more',
			[
				'label' => __( 'Use Read More', 'maco' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => 'Use',
				'label_off' => 'No',
				'return_value' => 'on',
				'default' => 'on',
			]
		);

		$this->add_control(
			'typhography_read_more_color',
			[
				'label' => __( 'Read More Title Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} a.read-more' => 'color: {{VALUE}}; border: 1px solid {{VALUE}}',
				],
				'condition' => [
					'use_read_more' => 'on',
				],
			]
		);

		$this->add_control(
			'read_more_title_hov_color',
			[
				'label' => __( 'Read More Hover Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} a.read-more:hover' => 'color: {{VALUE}};',
				],
				'condition' => [
					'use_read_more' => 'on',
				],
			]
		);

		$this->add_control(
			'read_more_bg_color_hov',
			[
				'label' => __( 'Read More Hover Background Color', 'maco' ),
				'type' => \Elementor\Controls_Manager::COLOR,	
				'default' => '#cb1313',
				'selectors' => [
					'{{WRAPPER}} a.read-more:hover' => 'background-color: {{VALUE}}; border: 1px solid {{VALUE}}',
				],
				'condition' => [
					'use_read_more' => 'on',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'typography_post_read_more',
				'label' => __( 'Read More Font Setting', 'maco' ),
				'selector' => '{{WRAPPER}} a.read-more, {{WRAPPER}} .post-masonry-style a.more, {{WRAPPER}} .main-news-5 .post-content .read-more-button a',
				'condition' => [
					'use_read_more' => 'on',
				],
			]
		);

		$this->add_control(
			'read_more_text',
			[
				'label' => __( 'Read More Text', 'maco' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => 'Read More',
				'title' => __( 'Enter some text', 'maco' ),
				'description' => __( 'Change the text with yours.', 'maco' ),
				'condition' => [
					'use_read_more' => 'on',
				],
			]
		);

		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block excerpt style setting
		-----------------------------------------------------------------------------------*/

		/*-----------------------------------------------------------------------------------*/
		/*  10. PAGINATION STYLE SETTING
		/*-----------------------------------------------------------------------------------*/
		$this->start_controls_section(
			'section_maco_post_pagination_style_setting',
			[
				'label' => __( 'Pagination Setting', 'maco' ),
			]
		);


		$this->end_controls_section();
		/*-----------------------------------------------------------------------------------
			end of post block pagination style setting
		-----------------------------------------------------------------------------------*/

	}

	protected function render() {

		$instance = $this->get_settings();

		/*-----------------------------------------------------------------------------------*/
		/*  VARIABLES LIST
		/*-----------------------------------------------------------------------------------*/
		/* POST SETTING VARIBALES */
		$category 			= ! empty( $instance['category'] ) ? $instance['category'] : '';
		$offset 			= ! empty( $instance['offset'] ) ? (int)$instance['offset'] : '';
		$post_per_page 		= ! empty( $instance['posts_per_page'] ) ? (int)$instance['posts_per_page'] : 6;
		$orderby 			= ! empty( $instance['orderby'] ) ? $instance['orderby'] : 'date';
		$use_masonry 		= $instance['use_masonry'];
		
		/* LAYOUT SETTING */
		$horizontal_use_left_def 			= $instance['horizontal_use_left_def'];
		$horizontal_col_select2 			= ! empty( $instance['horizontal_col_select2'] ) ? $instance['horizontal_col_select2'] : 'column-3';
		$horizontal_col_select2_tablet 		= ! empty( $instance['horizontal_col_select2_tablet'] ) ? $instance['horizontal_col_select2_tablet'] : 'tablet0-column-2';
		$horizontal_col_select2_mobile 		= ! empty( $instance['horizontal_col_select2_mobile'] ) ? $instance['horizontal_col_select2_mobile'] : 'mobile-column-1';

		/* IMAGE SETTING VARIBALES */
		$post_image_crop 	= $instance['post_image_crop'];
		$width 				= ! empty( $instance['width'] ) ? (int)$instance['width'] : 535;
		$height 			= ! empty( $instance['height'] ) ? (int)$instance['height'] : 355;

		// Style Setting
		$use_title 			= $instance['use_title'];
		$use_category 		= $instance['use_category'];
		$use_author 		= $instance['use_author'];
		$use_date	 		= $instance['use_date'];
		$use_excerpt 		= $instance['use_excerpt'];
		$use_read_more 		= $instance['use_read_more'];
		$read_more_text 	= ! empty( $instance['read_more_text'] ) ? $instance['read_more_text'] : 'Read More';
		$excerpt_word 		= ! empty( $instance['excerpt_word'] ) ? (int)$instance['excerpt_word'] : 30;

		/* PAGINATION SETTING */
		$post_pagination_type 	= ! empty( $instance['post_pagination_type'] ) ? $instance['post_pagination_type'] : 'post_pagination_none';

		// Pagination Prev/Next
		$pagination_next_text 	= ! empty( $instance['pagination_next_text'] ) ? $instance['pagination_next_text'] : 'NEWER POST';
		$pagination_prev_text 	= ! empty( $instance['pagination_prev_text'] ) ? $instance['pagination_prev_text'] : 'OLDER POST';

		// Pagination Infinte
		$loop_infinite_class 		= ! empty( $instance['loop_infinite_class'] ) ? $instance['loop_infinite_class'] : 'loop-infinte-post-list';
		$loop_infinite_text 		= ! empty( $instance['loop_infinite_text'] ) ? $instance['loop_infinite_text'] : 'Load More';
		//$loop_infinite_finish_text 	= ! empty( $instance['loop_infinite_finish_text'] ) ? $instance['loop_infinite_finish_text'] : 'There is no more';
		$loop_infinite_load_img 	= ! empty( $instance['loop_infinite_load_img'] ) ? $instance['loop_infinite_load_img'] : '';
		$load_style 				= ! empty( $instance['load_style'] ) ? $instance['load_style'] : 'style-1';
		$use_shadow_pagination 		=  $instance['use_shadow_pagination'];


		/* end of variables list */

		include ( plugin_dir_path(__FILE__).'tpl/post-block.php' );

		/*-----------------------------------------------------------------------------------
		  end of conditional end of post block, Alhamdulillah.
		-----------------------------------------------------------------------------------*/

		?>

		<?php

	}

	protected function content_template() {}

	public function render_plain_content( $instance = [] ) {}

}